package com.example.gpstest;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.provider.Settings;
import android.webkit.WebView;
import android.widget.TextView;
import android.widget.Toast;

public class GPSActivity extends Activity implements LocationListener {
	private TextView latituteField;
	private TextView longitudeField;
	private LocationManager locationManager;
	WebView position;

	/** Called when the activity is first created. */

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_gps);
		// testviews that we want to manipulate in the form
		latituteField = (TextView) findViewById(R.id.TextView02);
		longitudeField = (TextView) findViewById(R.id.TextView04);
		position = (WebView) findViewById(R.id.WebView);
		position.getSettings().setJavaScriptEnabled(true);

		// define locationManager, in this case, the service we are interested
		// in is location service
		locationManager = (LocationManager) getSystemService(Context.LOCATION_SERVICE);

		// check if GPS is enabled, if not, bring user to enable GPS window(in
		// comment) or display message
		boolean enabledGPS = locationManager
				.isProviderEnabled(LocationManager.GPS_PROVIDER);

		if (!enabledGPS) {
			// Intent intent = new
			// Intent(Settings.ACTION_LOCATION_SOURCE_SETTINGS);
			// startActivity(intent);
			Toast.makeText(getApplicationContext(), "Please enable GPS",
					Toast.LENGTH_SHORT).show();
		}

		// this line defines how frequent to update, 2nd parameter is the
		// frequency in time to update, 3rd parameter is frequency in distance
		// to update, 4th parameter is the listener
		locationManager.requestLocationUpdates(locationManager.GPS_PROVIDER,
				5000, 0, this);
	}

	// LocationListener implements 4 methods,
	// 1)onLocationChanged,2)onStatusChanged,3)onProviderEnabled,4)onProviderDisabled

	// This method defines the operation to be performed when a location is
	// changed
	public void onLocationChanged(Location location) {
		// get the lat and lng
		double lat = location.getLatitude();
		double lng = location.getLongitude();
		// set the textview in our form to display the lat and lng
		latituteField.setText(String.valueOf(lat));
		longitudeField.setText(String.valueOf(lng));
		String text = "My location is: Lat = " + lat + " Lgn = " + lng;
		Toast.makeText(getApplicationContext(), text, Toast.LENGTH_SHORT)
				.show();
		// this is the url to display the current location on google map
		String url = "http://maps.google.com/staticmap?center=" + lat + ","
				+ lng + "&zoom=18&size=512x512&maptype=mobile/&markers=" + lat
				+ "," + lng;
		// load the URL
		position.loadUrl(url);
	}

	// This method is called when status of service provider is changed such as
	// temporary unavailable to available
	public void onStatusChanged(String provider, int status, Bundle extras) {
		// TODO Auto-generated method stub
	}

	// This method is called when service provider is enabled
	public void onProviderEnabled(String provider) {
		Toast.makeText(this, "Enabled new provider " + provider,
				Toast.LENGTH_SHORT).show();
	}

	// This method is called when service provider is disabled
	public void onProviderDisabled(String provider) {
		Toast.makeText(this, "Disabled provider " + provider,
				Toast.LENGTH_SHORT).show();
	}
}
